@@ -1,14 +1,21 @@
 /*
-  Copyright (c) 2015, 2018 Oracle and/or its affiliates. All rights reserved.
+  Copyright (c) 2015, 2021, Oracle and/or its affiliates.
 
   This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; version 2 of the License.
+  it under the terms of the GNU General Public License, version 2.0,
+  as published by the Free Software Foundation.
+
+  This program is also distributed with certain software (including
+  but not limited to OpenSSL) that is licensed under separate terms,
+  as designated in a particular file or component or in included license
+  documentation.  The authors of MySQL hereby grant you an additional
+  permission to link the program and your derivative works with the
+  separately licensed software that they have included with MySQL.
 
   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-  GNU General Public License for more details.
+  GNU General Public License, version 2.0, for more details.
 
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
@@ -172,6 +179,17 @@ void Sql_formatter::format_row_group(Row_group_dump_task* row_group)
   row_string+= ";\n";
 
   this->append_output(row_string);
+  /*
+    user account is dumped in the form of INSERT statements, thus meed to 
+    append FLUSH PRIVILEGES
+  */
+  if (!use_show_create_user) {
+    std::string schema = row_group->m_source_table->get_schema();
+    std::string name = row_group->m_source_table->get_name();
+    if ((schema == "mysql") && (name == "user")) {
+      this->append_output("/*! FLUSH PRIVILEGES */;\n");
+    }
+  }
 }
 
 void Sql_formatter::format_table_indexes(
