@@ -1,5 +1,5 @@
 //
-// Copyright (C) 2010-2018 Codership Oy <info@codership.com>
+// Copyright (C) 2010-2021 Codership Oy <info@codership.com>
 //
 
 //! @file replicator_smm.hpp
@@ -159,7 +159,7 @@ namespace galera
                                  wsrep_seqno_t seqno_l);
         void process_state_req(void* recv_ctx, const void* req,
                                size_t req_size, wsrep_seqno_t seqno_l,
-                               wsrep_seqno_t donor_seq);
+                               wsrep_seqno_t donor_seq, const char* requestor_id);
         void process_join(wsrep_seqno_t seqno, wsrep_seqno_t seqno_l);
         void process_sync(wsrep_seqno_t seqno_l);
 
@@ -622,6 +622,12 @@ namespace galera
         gu::Cond      sst_cond_;
 #endif /* HAVE_PSI_INTERFACE */
         int           sst_retry_sec_;
+        enum st_type
+        {
+            ST_TYPE_NONE,
+            ST_TYPE_SST,
+            ST_TYPE_IST
+        } last_st_type_;
 
         // services
         gcache::GCache gcache_;
