@@ -113,6 +113,7 @@ typedef enum status_vars
     STATS_APPLY_OOOE,
     STATS_APPLY_OOOL,
     STATS_APPLY_WINDOW,
+    STATS_APPLY_WAITS,
     STATS_COMMIT_OOOE,
     STATS_COMMIT_OOOL,
     STATS_COMMIT_WINDOW,
@@ -174,6 +175,7 @@ static const struct wsrep_stats_var wsrep_stats[STATS_MAX + 1] =
     { "apply_oooe",               WSREP_VAR_DOUBLE, { 0 }  },
     { "apply_oool",               WSREP_VAR_DOUBLE, { 0 }  },
     { "apply_window",             WSREP_VAR_DOUBLE, { 0 }  },
+    { "apply_waits",              WSREP_VAR_INT64,  { 0 }  },
     { "commit_oooe",              WSREP_VAR_DOUBLE, { 0 }  },
     { "commit_oool",              WSREP_VAR_DOUBLE, { 0 }  },
     { "commit_window",            WSREP_VAR_DOUBLE, { 0 }  },
@@ -279,21 +281,19 @@ galera::ReplicatorSMM::stats_get()
     double oooe;
     double oool;
     double win;
-    const_cast<Monitor<ApplyOrder>&>(apply_monitor_).
-        get_stats(&oooe, &oool, &win);
+    long long waits;
+    apply_monitor_.get_stats(&oooe, &oool, &win, &waits);
 
     sv[STATS_APPLY_OOOE          ].value._double = oooe;
     sv[STATS_APPLY_OOOL          ].value._double = oool;
     sv[STATS_APPLY_WINDOW        ].value._double = win;
-
-    const_cast<Monitor<CommitOrder>&>(commit_monitor_).
-        get_stats(&oooe, &oool, &win);
+    sv[STATS_APPLY_WAITS         ].value._int64 = waits;
+    commit_monitor_.get_stats(&oooe, &oool, &win, &waits);
 
     sv[STATS_COMMIT_OOOE         ].value._double = oooe;
     sv[STATS_COMMIT_OOOL         ].value._double = oool;
     sv[STATS_COMMIT_WINDOW       ].value._double = win;
 
-
     sv[STATS_LOCAL_STATE         ].value._int64  = state2stats(state_());
     sv[STATS_LOCAL_STATE_COMMENT ].value._string = state2stats_str(state_(),
                                                                    sst_state_);
