@@ -1,4 +1,4 @@
-/* Copyright (c) 2005, 2017, Oracle and/or its affiliates. All rights reserved.
+/* Copyright (c) 2005, 2021, Oracle and/or its affiliates.
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License, version 2.0,
@@ -40,7 +40,9 @@
 
 #include "mysql/psi/mysql_sp.h"
 
+#ifdef WITH_WSREP
 #include "wsrep_thd.h"
+#endif
 
 /**
   @addtogroup Event_Scheduler
@@ -529,7 +531,7 @@ Event_queue_element::load_from_row(THD *thd, TABLE *table)
     Hence, if ET_FIELD_EXECUTE_AT is empty there is an error.
   */
   execute_at_null= table->field[ET_FIELD_EXECUTE_AT]->is_null();
-  DBUG_ASSERT(!(starts_null && ends_null && !expression && execute_at_null));
+  assert(!(starts_null && ends_null && !expression && execute_at_null));
   if (!expression && !execute_at_null)
   {
     if (table->field[ET_FIELD_EXECUTE_AT]->get_date(&time,
@@ -724,7 +726,7 @@ bool get_next_time(const Time_zone *time_zone, my_time_t *next,
   DBUG_ENTER("get_next_time");
   DBUG_PRINT("enter", ("start: %lu  now: %lu", (long) start, (long) time_now));
 
-  DBUG_ASSERT(start <= time_now);
+  assert(start <= time_now);
 
   longlong months=0, seconds=0;
 
@@ -770,7 +772,7 @@ bool get_next_time(const Time_zone *time_zone, my_time_t *next,
     DBUG_RETURN(1);
     break;
   case INTERVAL_LAST:
-    DBUG_ASSERT(0);
+    assert(0);
   }
   DBUG_PRINT("info", ("seconds: %ld  months: %ld", (long) seconds, (long) months));
 
@@ -814,7 +816,7 @@ bool get_next_time(const Time_zone *time_zone, my_time_t *next,
         then next_time was set, but perhaps to the value that is less
         then time_now.  See below for elaboration.
       */
-      DBUG_ASSERT(negative || next_time > 0);
+      assert(negative || next_time > 0);
 
       /*
         If local_now < local_start, i.e. STARTS time is in the future
@@ -912,7 +914,7 @@ bool get_next_time(const Time_zone *time_zone, my_time_t *next,
     }
   }
 
-  DBUG_ASSERT(time_now < next_time);
+  assert(time_now < next_time);
 
   *next= next_time;
 
@@ -1433,7 +1435,7 @@ Event_job_data::execute(THD *thd, bool drop)
   {
     sp_head *sphead= thd->lex->sphead;
 
-    DBUG_ASSERT(sphead);
+    assert(sphead);
 
     if (thd->enable_slow_log)
       sphead->m_flags|= sp_head::LOG_SLOW_STATEMENTS;
