@@ -1,4 +1,4 @@
-/* Copyright (c) 2010, 2018, Oracle and/or its affiliates. All rights reserved.
+/* Copyright (c) 2010, 2021, Oracle and/or its affiliates.
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License, version 2.0,
@@ -151,7 +151,7 @@ bool Rpl_info_factory::change_mi_repository(Master_info *mi,
   uint instances= 1;
   DBUG_ENTER("Rpl_info_factory::change_mi_repository");
 
-  DBUG_ASSERT(handler_src);
+  assert(handler_src);
 
   if (init_repositories(mi_table_data, mi_file_data, mi_option, instances,
                         NULL, &handler_dest, msg))
@@ -326,7 +326,7 @@ bool Rpl_info_factory::change_rli_repository(Relay_log_info *rli,
   uint instances= 1;
   DBUG_ENTER("Rpl_info_factory::change_rli_repository");
 
-  DBUG_ASSERT(handler_src != NULL);
+  assert(handler_src != NULL);
 
   if (init_repositories(rli_table_data, rli_file_data, rli_option,
                         instances, NULL, &handler_dest, msg))
@@ -456,8 +456,8 @@ Slave_worker *Rpl_info_factory::create_worker(uint rli_option, uint worker_id,
 
   /* get_num_instances() requires channel_map lock */
   /*
-  DBUG_ASSERT(channel_map.get_num_instances() <= 1 ||
-              (rli_option == 1 && handler_dest->get_rpl_info_type() == 1));
+    assert(channel_map.get_num_instances() <= 1 ||
+    (rli_option == 1 && handler_dest->get_rpl_info_type() == 1));
   */
   if (decide_repository(worker, rli_option, &handler_src, &handler_dest, &msg))
     goto err;
@@ -506,7 +506,7 @@ static void build_worker_info_name(char* to,
                                    const char* path,
                                    const char* fname)
 {
-  DBUG_ASSERT(to);
+  assert(to);
   char* pos= to;
   if (path[0])
     pos= my_stpcpy(pos, path);
@@ -614,8 +614,8 @@ bool Rpl_info_factory::decide_repository(Rpl_info *info, uint option,
     goto err;
   }
 
-  DBUG_ASSERT((*handler_src) != NULL && (*handler_dest) != NULL &&
-              (*handler_src) != (*handler_dest));
+  assert((*handler_src) != NULL && (*handler_dest) != NULL &&
+         (*handler_src) != (*handler_dest));
 
   return_check_src= check_src_repository(info, option, handler_src);
   return_check_dst= (*handler_dest)->do_check_info(info->get_internal_id()); // approx via scan, not field_values! Todo: reconsider any need for that at least in the Worker case
@@ -699,7 +699,7 @@ bool Rpl_info_factory::decide_repository(Rpl_info *info, uint option,
     else if (return_check_src == REPOSITORY_DOES_NOT_EXIST &&
              return_check_dst == REPOSITORY_EXISTS)
     {
-      DBUG_ASSERT(info->get_rpl_info_handler() == NULL);
+      assert(info->get_rpl_info_handler() == NULL);
       if ((*handler_dest)->do_init_info(info->get_internal_id()))
       {
         *msg= "Error reading repository";
@@ -708,8 +708,8 @@ bool Rpl_info_factory::decide_repository(Rpl_info *info, uint option,
     }
     else
     {
-      DBUG_ASSERT(return_check_src == REPOSITORY_DOES_NOT_EXIST &&
-                  return_check_dst == REPOSITORY_DOES_NOT_EXIST);
+      assert(return_check_src == REPOSITORY_DOES_NOT_EXIST &&
+             return_check_dst == REPOSITORY_DOES_NOT_EXIST);
       info->inited= false;
     }
 
@@ -912,7 +912,7 @@ bool Rpl_info_factory::init_repositories(const struct_table_data table_data,
 
   DBUG_ENTER("Rpl_info_factory::init_mi_repositories");
 
-  DBUG_ASSERT(handler_dest != NULL);
+  assert(handler_dest != NULL);
   switch (rep_option)
   {
     case INFO_REPOSITORY_FILE:
@@ -951,7 +951,7 @@ bool Rpl_info_factory::init_repositories(const struct_table_data table_data,
     break;
 
     default:
-      DBUG_ASSERT(0);
+      assert(0);
   }
   error= FALSE;
 
@@ -968,7 +968,7 @@ bool Rpl_info_factory::scan_repositories(uint* found_instances,
   bool error= false;
   uint file_instances= 0;
   uint table_instances= 0;
-  DBUG_ASSERT(found_rep_option != NULL);
+  assert(found_rep_option != NULL);
 
   DBUG_ENTER("Rpl_info_factory::scan_repositories");
 
@@ -1331,7 +1331,7 @@ Rpl_info_factory::load_channel_names_from_repository(std::vector<std::string>& c
   switch(mi_repository)
   {
   case INFO_REPOSITORY_FILE:
-    DBUG_ASSERT(mi_instances == 1);
+    assert(mi_instances == 1);
     /* insert default channel */
     {
     std::string str(default_channel);
@@ -1348,7 +1348,7 @@ Rpl_info_factory::load_channel_names_from_repository(std::vector<std::string>& c
     /* file and table instanaces are zero, nothing to be done*/
     break;
   default:
-    DBUG_ASSERT(0);
+    assert(0);
   }
 
   DBUG_RETURN(false);
