@@ -1,4 +1,4 @@
-/* Copyright (c) 2000, 2018, Oracle and/or its affiliates. All rights reserved.
+/* Copyright (c) 2000, 2021, Oracle and/or its affiliates.
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License, version 2.0,
@@ -81,7 +81,7 @@ bool trans_check_state(THD *thd)
     Always commit statement transaction before manipulating with
     the normal one.
   */
-  DBUG_ASSERT(thd->get_transaction()->is_empty(Transaction_ctx::STMT));
+  assert(thd->get_transaction()->is_empty(Transaction_ctx::STMT));
 
   if (unlikely(thd->in_sub_stmt))
   {
@@ -125,7 +125,7 @@ bool trans_begin(THD *thd, uint flags)
 
   thd->locked_tables_list.unlock_locked_tables(thd);
 
-  DBUG_ASSERT(!thd->locked_tables_mode);
+  assert(!thd->locked_tables_mode);
 
   if (thd->in_multi_stmt_transaction_mode() ||
       (thd->variables.option_bits & OPTION_TABLE_LOCK))
@@ -156,8 +156,8 @@ bool trans_begin(THD *thd, uint flags)
   thd->mdl_context.release_transactional_locks();
 
   // The RO/RW options are mutually exclusive.
-  DBUG_ASSERT(!((flags & MYSQL_START_TRANS_OPT_READ_ONLY) &&
-                (flags & MYSQL_START_TRANS_OPT_READ_WRITE)));
+  assert(!((flags & MYSQL_START_TRANS_OPT_READ_ONLY) &&
+           (flags & MYSQL_START_TRANS_OPT_READ_WRITE)));
   if (flags & MYSQL_START_TRANS_OPT_READ_ONLY)
   {
     thd->tx_read_only= true;
@@ -184,7 +184,7 @@ bool trans_begin(THD *thd, uint flags)
   }
 
   DBUG_EXECUTE_IF("dbug_set_high_prio_trx", {
-    DBUG_ASSERT(thd->tx_priority==0);
+    assert(thd->tx_priority==0);
 #ifdef WITH_WSREP
     WSREP_WARN("InnoDB High Priority being used: %d -> %d", thd->tx_priority, 1);
 #endif /* WITH_WSREP */
@@ -285,7 +285,7 @@ bool trans_commit(THD *thd)
   thd->lex->start_transaction_opt= 0;
 
   /* The transaction should be marked as complete in P_S. */
-  DBUG_ASSERT(thd->m_transaction_psi == NULL);
+  assert(thd->m_transaction_psi == NULL);
 
   thd->tx_priority= 0;
 
@@ -319,9 +319,9 @@ bool trans_commit_implicit(THD *thd)
     by asserting that conditions that are checked in the former function are
     true.
   */
-  DBUG_ASSERT(thd->get_transaction()->is_empty(Transaction_ctx::STMT) &&
-              !thd->in_sub_stmt &&
-              !thd->get_transaction()->xid_state()->check_in_xa(false));
+  assert(thd->get_transaction()->is_empty(Transaction_ctx::STMT) &&
+         !thd->in_sub_stmt &&
+         !thd->get_transaction()->xid_state()->check_in_xa(false));
 
   if (thd->in_multi_stmt_transaction_mode() ||
       (thd->variables.option_bits & OPTION_TABLE_LOCK))
@@ -351,7 +351,7 @@ bool trans_commit_implicit(THD *thd)
   thd->get_transaction()->reset_unsafe_rollback_flags(Transaction_ctx::SESSION);
 
   /* The transaction should be marked as complete in P_S. */
-  DBUG_ASSERT(thd->m_transaction_psi == NULL);
+  assert(thd->m_transaction_psi == NULL);
 
   /*
     Upon implicit commit, reset the current transaction
@@ -400,7 +400,7 @@ bool trans_rollback(THD *thd)
   thd->lex->start_transaction_opt= 0;
 
   /* The transaction should be marked as complete in P_S. */
-  DBUG_ASSERT(thd->m_transaction_psi == NULL);
+  assert(thd->m_transaction_psi == NULL);
 
   thd->tx_priority= 0;
 
@@ -436,8 +436,8 @@ bool trans_rollback_implicit(THD *thd)
     Don't perform rollback in the middle of sub-statement, wait till
     its end.
   */
-  DBUG_ASSERT(thd->get_transaction()->is_empty(Transaction_ctx::STMT) &&
-              !thd->in_sub_stmt);
+  assert(thd->get_transaction()->is_empty(Transaction_ctx::STMT) &&
+         !thd->in_sub_stmt);
 
 #ifdef WITH_WSREP
   wsrep_register_hton(thd, true);
@@ -451,9 +451,9 @@ bool trans_rollback_implicit(THD *thd)
     Transaction_ctx::SESSION);
 
   /* Rollback should clear transaction_rollback_request flag. */
-  DBUG_ASSERT(!thd->transaction_rollback_request);
+  assert(!thd->transaction_rollback_request);
   /* The transaction should be marked as complete in P_S. */
-  DBUG_ASSERT(thd->m_transaction_psi == NULL);
+  assert(thd->m_transaction_psi == NULL);
 
   trans_track_end_trx(thd);
 
@@ -486,13 +486,13 @@ bool trans_commit_stmt(THD *thd)
     a savepoint for each nested statement, and release the
     savepoint when statement has succeeded.
   */
-  DBUG_ASSERT(! thd->in_sub_stmt);
+  assert(! thd->in_sub_stmt);
 
   /*
     Some code in MYSQL_BIN_LOG::commit and ha_commit_low() is not safe
     for attachable transactions.
   */
-  DBUG_ASSERT(!thd->is_attachable_ro_transaction_active());
+  assert(!thd->is_attachable_ro_transaction_active());
 
   thd->get_transaction()->merge_unsafe_rollback_flags();
 
@@ -519,8 +519,8 @@ bool trans_commit_stmt(THD *thd)
         notify_after_transaction_commit(thd))
       sql_print_warning("Failed to collect GTID to send in the response packet!");
   /* In autocommit=1 mode the transaction should be marked as complete in P_S */
-  DBUG_ASSERT(thd->in_active_multi_stmt_transaction() ||
-              thd->m_transaction_psi == NULL);
+  assert(thd->in_active_multi_stmt_transaction() ||
+         thd->m_transaction_psi == NULL);
 
   thd->get_transaction()->reset(Transaction_ctx::STMT);
 
@@ -546,13 +546,13 @@ bool trans_rollback_stmt(THD *thd)
     a savepoint for each nested statement, and release the
     savepoint when statement has succeeded.
   */
-  DBUG_ASSERT(! thd->in_sub_stmt);
+  assert(! thd->in_sub_stmt);
 
   /*
     Some code in MYSQL_BIN_LOG::rollback and ha_rollback_low() is not safe
     for attachable transactions.
   */
-  DBUG_ASSERT(!thd->is_attachable_ro_transaction_active());
+  assert(!thd->is_attachable_ro_transaction_active());
 
   thd->get_transaction()->merge_unsafe_rollback_flags();
 
@@ -589,10 +589,10 @@ bool trans_rollback_stmt(THD *thd)
   }
 
   /* In autocommit=1 mode the transaction should be marked as complete in P_S */
-  DBUG_ASSERT(thd->in_active_multi_stmt_transaction() ||
-              thd->m_transaction_psi == NULL ||
-              /* Todo: BUG#20488921 is in the way. */
-              DBUG_EVALUATE_IF("simulate_xa_commit_log_failure", true, false));
+  assert(thd->in_active_multi_stmt_transaction() ||
+         thd->m_transaction_psi == NULL ||
+         /* Todo: BUG#20488921 is in the way. */
+         DBUG_EVALUATE_IF("simulate_xa_commit_log_failure", true, false));
 
   thd->get_transaction()->reset(Transaction_ctx::STMT);
 
@@ -618,17 +618,17 @@ bool trans_commit_attachable(THD *thd)
   int res= 0;
 
   /* This function only handles attachable transactions. */
-  DBUG_ASSERT(thd->is_attachable_ro_transaction_active());
+  assert(thd->is_attachable_ro_transaction_active());
 
   /*
     Since the attachable transaction is AUTOCOMMIT we only need to commit
     statement transaction.
   */
-  DBUG_ASSERT(! thd->get_transaction()->is_active(Transaction_ctx::SESSION));
+  assert(! thd->get_transaction()->is_active(Transaction_ctx::SESSION));
 
   /* Attachable transactions should not do anything unsafe. */
-  DBUG_ASSERT(!thd->get_transaction()->
-                 cannot_safely_rollback(Transaction_ctx::STMT));
+  assert(!thd->get_transaction()->
+         cannot_safely_rollback(Transaction_ctx::STMT));
 
 
   if (thd->get_transaction()->is_active(Transaction_ctx::STMT))
@@ -636,7 +636,7 @@ bool trans_commit_attachable(THD *thd)
     res= ha_commit_attachable(thd);
   }
 
-  DBUG_ASSERT(thd->m_transaction_psi == NULL);
+  assert(thd->m_transaction_psi == NULL);
 
   thd->get_transaction()->reset(Transaction_ctx::STMT);
 
@@ -813,12 +813,14 @@ bool trans_rollback_to_savepoint(THD *thd, LEX_STRING name)
 
   thd->get_transaction()->m_savepoints= sv;
 
+#ifdef WITH_WSREP
   /*
     Release metadata locks that were acquired during this savepoint unit
     unless binlogging is on. Releasing locks with binlogging on can break
     replication as it allows other connections to drop these tables before
     rollback to savepoint is written to the binlog.
   */
+#endif /* WITH_WSREP */
   if (!res && mdl_can_safely_rollback_to_savepoint)
     thd->mdl_context.rollback_to_savepoint(sv->mdl_savepoint);
 
