@@ -2168,6 +2168,13 @@ row_upd_store_v_row(
 								col_no);
 						dfield_copy_data(dfield, vfield);
 						dfield_dup(dfield, node->heap);
+						if (dfield_is_null(dfield)) {
+						  innobase_get_computed_value(
+							node->row, col, index,
+							&heap, node->heap, NULL,
+							thd, mysql_table, NULL,
+							NULL, NULL, prebuilt);
+						}
 					}
 				} else {
 					/* Need to compute, this happens when
